"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MathJax3Renderer = exports.Mathjax2Renderer = void 0;
const model_1 = require("./model");
const lodash_es_1 = require("lodash-es");
const load_script_css_1 = require("@cnblogs/load-script-css");
class Mathjax2Renderer {
    constructor() {
        this._defaultConfig = model_1.defaultConfig[model_1.MathEngine.MathJax2];
        this._defaultMathJaxConfig = {
            tex2jax: {
                inlineMath: [
                    ['$', '$'],
                    ['\\(', '\\)'],
                ],
                processClass: 'math',
                processEscapes: true,
            },
            TeX: {
                equationNumbers: {
                    autoNumber: 'AMS',
                    useLabelIds: true,
                },
                extensions: ['extpfeil.js', 'mediawiki-texvc.js'],
                Macros: { bm: '\\boldsymbol' },
            },
            'HTML-CSS': { linebreaks: { automatic: true } },
            SVG: { linebreaks: { automatic: true } },
            skipStartupTypeset: true,
        };
        this._config = this._defaultConfig;
    }
    get _global() {
        return window;
    }
    render(container) {
        return this.init()
            .then(mathjax => {
            if (!mathjax)
                return;
            const { onRendered } = this._config;
            mathjax.Hub.Queue(['Typeset', mathjax.Hub, container]);
            if (onRendered != null) {
                mathjax.Hub.Queue(() => onRendered(mathjax));
            }
        })
            .catch(console.warn);
    }
    config(value) {
        this._config = (0, lodash_es_1.merge)({}, this._defaultConfig, value);
        return this;
    }
    init() {
        if (this._initTask)
            return this._initTask;
        const { entryScript, tapMathJaxConfig, document } = this._config;
        return (this._initTask = (0, load_script_css_1.loadScript)({
            src: entryScript,
            id: 'mathjax',
            timeoutSeconds: 10,
            appendTo: document.head,
        }).then(() => {
            var _a;
            const { MathJax } = this._global;
            if (MathJax) {
                MathJax.Hub.Config((_a = tapMathJaxConfig === null || tapMathJaxConfig === void 0 ? void 0 : tapMathJaxConfig.call(undefined, Object.assign({}, this._defaultMathJaxConfig))) !== null && _a !== void 0 ? _a : this._defaultMathJaxConfig);
                MathJax.Hub.Configured();
                return MathJax;
            }
        }));
    }
}
exports.Mathjax2Renderer = Mathjax2Renderer;
class MathJax3Renderer {
    constructor() {
        this._defaultConfig = model_1.defaultConfig[model_1.MathEngine.MathJax3];
        this._defaultMathJaxConfig = {
            tex: {
                inlineMath: [
                    ['$', '$'],
                    ['\\(', '\\)'],
                ],
                processEscapes: true,
                tags: 'ams',
                useLabelIds: true,
                macros: {
                    bm: '\\boldsymbol',
                },
                packages: { '[+]': ['noerrors', 'extpfeil'] },
            },
            options: {
                processHtmlClass: 'math',
                ignoreHtmlClass: 'tex2jax_ignore',
            },
            loader: {
                load: ['[tex]/noerrors', '[tex]/extpfeil'],
            },
            startup: {
                typeset: false,
            },
        };
        this._config = this._defaultConfig;
    }
    config(value) {
        this._config = (0, lodash_es_1.merge)({}, this._defaultConfig, value);
        return this;
    }
    render(container) {
        return this.init()
            .then(mathjax => mathjax
            ? (mathjax.startup.promise = mathjax.startup.promise.then(() => mathjax.typesetPromise([container])))
            : undefined)
            .catch(console.warn);
    }
    init() {
        var _a;
        return ((_a = this._initTask) !== null && _a !== void 0 ? _a : (this._initTask = new Promise((resolve, reject) => {
            var _a;
            const { entryScript, tapMathJaxConfig, document: _document } = this._config;
            const _window = ((_a = _document.defaultView) !== null && _a !== void 0 ? _a : window);
            (_window.setMathJaxConfig = () => {
                var _a, _b;
                const __window = window;
                __window.MathJax = (_a = tapMathJaxConfig === null || tapMathJaxConfig === void 0 ? void 0 : tapMathJaxConfig.call(undefined, Object.assign({}, this._defaultMathJaxConfig))) !== null && _a !== void 0 ? _a : Object.assign({}, this._defaultMathJaxConfig);
                if ((_b = __window.MathJax) === null || _b === void 0 ? void 0 : _b.startup)
                    __window.MathJax.startup.ready = () => resolve(_window.MathJax);
            })();
            (0, load_script_css_1.loadScript)({
                src: entryScript,
                id: 'mathjax',
                executionStrategy: 'defer',
            }).catch(() => { });
        })));
    }
}
exports.MathJax3Renderer = MathJax3Renderer;
//# sourceMappingURL=impl.js.map